package com.klipwallet.app2app.api.request;

import com.klipwallet.app2app.api.KlipProtocol;

import org.json.JSONException;
import org.json.JSONObject;

/**
 * Sign Message 요청 정보
 */
public class SignMessageRequest implements KlipRequest {
    private String value;
    private String from;

    public static class Builder {
        private String value;
        private String from;

        public Builder() {
        }

        /**
         * 서명할 원문을 입력한다.
         * @param val original sign message
         * @return SignRequest.Builder
         */
        public Builder value(String val) {
            value = val;
            return this;
        }

        /**
         * (optional) 서명하는 계정 주소를 입력한다.
         * @param val EOA
         * @return SignRequest.Builder
         */
        public Builder from(String val) {
            from = val;
            return this;
        }

        public SignMessageRequest build() {
            return new SignMessageRequest(this);
        }
    }

    public SignMessageRequest(Builder builder) {
        value = builder.value;
        from = builder.from;
    }

    @Override
    public JSONObject toJson() {
        JSONObject obj = new JSONObject();
        try {
            obj.put(KlipProtocol.VALUE, value);
            obj.put(KlipProtocol.FROM, from);
            return obj;
        } catch (JSONException e) {
            throw new IllegalArgumentException("JSON parsing error. Malformed parameters were provided. detailed error message: " + e.toString());
        }
    }
}
